# scrapyish

__`sprapyish`__ expiremental `scrapy`-like web crawling project that uses `playwright` for javascript rendering.
The project aims to fill the void that exists because `scrapy-playwright` does not natively support window OS.

## Version 0.0.2

